# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from notifications_server_connector.models.wrapped_response_portal_template_override_response import WrappedResponsePortalTemplateOverrideResponse  # noqa: E501

class TestWrappedResponsePortalTemplateOverrideResponse(unittest.TestCase):
    """WrappedResponsePortalTemplateOverrideResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponsePortalTemplateOverrideResponse:
        """Test WrappedResponsePortalTemplateOverrideResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponsePortalTemplateOverrideResponse`
        """
        model = WrappedResponsePortalTemplateOverrideResponse()  # noqa: E501
        if include_optional:
            return WrappedResponsePortalTemplateOverrideResponse(
                done = True,
                result = notifications_server_connector.models.portal_template_override_response.PortalTemplateOverrideResponse(
                    source_type_id = 56, 
                    source_type = notifications_server_connector.models.overridable_source_type_response.OverridableSourceTypeResponse(
                        id = 56, 
                        name = '', 
                        allowed_variables = [
                            ''
                            ], ), 
                    subject = '', 
                    body = '', 
                    is_override = True, 
                    created_at = 56, 
                    updated_at = 56, )
            )
        else:
            return WrappedResponsePortalTemplateOverrideResponse(
                result = notifications_server_connector.models.portal_template_override_response.PortalTemplateOverrideResponse(
                    source_type_id = 56, 
                    source_type = notifications_server_connector.models.overridable_source_type_response.OverridableSourceTypeResponse(
                        id = 56, 
                        name = '', 
                        allowed_variables = [
                            ''
                            ], ), 
                    subject = '', 
                    body = '', 
                    is_override = True, 
                    created_at = 56, 
                    updated_at = 56, ),
        )
        """

    def testWrappedResponsePortalTemplateOverrideResponse(self):
        """Test WrappedResponsePortalTemplateOverrideResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
